@@ -24,7 +24,7 @@ import re
 import glob
 from userprefs import Options, UserPrefs
 from cache import WCache
-from vars import Vars
+from vars import Vars, getuser
 from utils import *
 from msg import *
 
@@ -469,6 +469,11 @@ class RAInfo(object):
                 common_warn("%s: action %s not advertised in meta-data, it may not be supported by the RA" % (id,op))
                 rc |= 1
                 continue
+	    if "interval" in n_ops[op]:
+                if op == "start" or op == "stop":
+                    v = n_ops[op]["interval"]
+                    if crm_msec(v) != 0:
+                        common_warn("%s: Specified interval for %s is %s, it must be 0" %(id,op,v))
             try:
                 adv_timeout = self.actions()[op]["timeout"]
             except:
@@ -628,7 +633,7 @@ def disambiguate_ra_type(s):
     '''
     l = s.split(':')
     if not l or len(l) > 3:
-        return None
+        return ["","",""]
     if len(l) == 3:
         return l
     elif len(l) == 2:
